==> App-Manoc-2.99.2-TRIAL.tar.gz: App-Manoc-2.99.2/lib/App/Manoc/DB/Result/Rack.pm <==
package App::Manoc::DB::Result::Rack;
#ABSTRACT: A model object for racks

use strict;
use warnings;

our $VERSION = '2.99.2'; ##TRIAL VERSION

use parent 'App::Manoc::DB::Result';

__PACKAGE__->table('racks');
__PACKAGE__->add_columns(
    id => {
        data_type         => 'int',
        is_nullable       => 0,
        is_auto_increment => 1,
    },
    name => {
        data_type => 'varchar',
        size      => '32',
    },
    building_id => {
        data_type      => 'int',
        is_nullable    => 0,
        is_foreign_key => 1,
    },
    floor => {
        data_type   => 'varchar',
        size        => '4',
        is_nullable => 0,
    },
    room => {
        data_type   => 'varchar',
        size        => '16',
        is_nullable => 0,
    },
    notes => {
        data_type   => 'text',
        is_nullable => 1,
    }
);

__PACKAGE__->set_primary_key('id');
__PACKAGE__->add_unique_constraint( [qw/name/] );

__PACKAGE__->belongs_to(
    building => 'App::Manoc::DB::Result::Building',
    'building_id'
);

__PACKAGE__->has_many(
    hwassets => 'App::Manoc::DB::Result::HWAsset',
    'rack_id',
    { cascade_delete => 0 }
);

__PACKAGE__->has_many(
    devices => 'App::Manoc::DB::Result::Device',
    'rack_id',
    { cascade_delete => 1 }
);


sub label {
    my $self = shift;
    return $self->name . " (" . $self->building->name . ")";
}

1;

__END__

=pod

=head1 NAME

App::Manoc::DB::Result::Rack - A model object for racks

=head1 VERSION

version 2.99.2

=head1 METHODS

=head2 label

Return a string describing the object

=head1 AUTHORS

=over 4

=item *

Gabriele Mambrini <gmambro@cpan.org>

=item *

Enrico Liguori

=back

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2017 by Gabriele Mambrini.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

==> App-Manoc-2.99.3-TRIAL.tar.gz: App-Manoc-2.99.3/lib/App/Manoc/DB/Result/Rack.pm <==
package App::Manoc::DB::Result::Rack;
#ABSTRACT: A model object for racks

use strict;
use warnings;

our $VERSION = '2.99.3'; ##TRIAL VERSION

use parent 'App::Manoc::DB::Result';

__PACKAGE__->table('racks');
__PACKAGE__->add_columns(
    id => {
        data_type         => 'int',
        is_nullable       => 0,
        is_auto_increment => 1,
    },
    name => {
        data_type => 'varchar',
        size      => '32',
    },
    building_id => {
        data_type      => 'int',
        is_nullable    => 0,
        is_foreign_key => 1,
    },
    floor => {
        data_type   => 'varchar',
        size        => '4',
        is_nullable => 0,
    },
    room => {
        data_type   => 'varchar',
        size        => '16',
        is_nullable => 0,
    },
    notes => {
        data_type   => 'text',
        is_nullable => 1,
    }
);

__PACKAGE__->set_primary_key('id');
__PACKAGE__->add_unique_constraint( [qw/name/] );

__PACKAGE__->belongs_to(
    building => 'App::Manoc::DB::Result::Building',
    'building_id'
);

__PACKAGE__->has_many(
    hwassets => 'App::Manoc::DB::Result::HWAsset',
    'rack_id',
    { cascade_delete => 0 }
);

__PACKAGE__->has_many(
    devices => 'App::Manoc::DB::Result::Device',
    'rack_id',
    { cascade_delete => 1 }
);


sub label {
    my $self = shift;
    return $self->name . ' (' . $self->building->name . ')';
}

1;

__END__

=pod

=head1 NAME

App::Manoc::DB::Result::Rack - A model object for racks

=head1 VERSION

version 2.99.3

=head1 METHODS

=head2 label

Return a string describing the object

=head1 AUTHORS

=over 4

=item *

Gabriele Mambrini <gmambro@cpan.org>

=item *

Enrico Liguori

=back

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2017 by Gabriele Mambrini.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
